@@ -1,6 +1,7 @@
 package Thing;
 use strict;
-use Spiffy '-base';
+use Spiffy ();
+use base 'Spiffy';
 our @EXPORT = qw(thing);
 
 attribute volume => 11;
